@@ -206,6 +206,25 @@ def test_nxobject_getitem_by_class(nxroot):
     assert set(nxroot['entry'][NXevent_data]) == {'events_0', 'events_1'}
 
 
+def test_nxobject_getitem_by_class_get_fields(nxroot):
+    nxroot['entry'].create_class('log', NXlog)
+    nxroot['entry'].create_class('events_0', NXevent_data)
+    nxroot['entry']['field1'] = sc.arange('event', 4.0, unit='ns')
+    nxroot['entry']['field2'] = sc.arange('event', 2.0, unit='ns')
+    assert list(nxroot[Field]) == []
+    assert set(nxroot['entry'][Field]) == {'field1', 'field2'}
+
+
+def test_nxobject_getitem_by_class_list(nxroot):
+    nxroot['entry'].create_class('log', NXlog)
+    nxroot['entry'].create_class('events_0', NXevent_data)
+    nxroot['entry'].create_class('events_1', NXevent_data)
+    nxroot['entry']['field1'] = sc.arange('event', 4.0, unit='ns')
+    assert set(nxroot['entry'][[NXlog,
+                                NXevent_data]]) == {'log', 'events_0', 'events_1'}
+    assert set(nxroot['entry'][[NXlog, Field]]) == {'log', 'field1'}
+
+
 def test_nxobject_dataset_items_are_returned_as_Field(nxroot):
     events = nxroot['entry'].create_class('events_0', NXevent_data)
     events['event_time_offset'] = sc.arange('event', 5)
@@ -250,6 +269,23 @@ def test_field_unit_is_none_if_no_units_attribute(nxroot):
     assert field.unit is None
 
 
+@pytest.mark.parametrize('value,type_', [(1.2, float), (123, int), ('abc', str),
+                                         (True, bool)])
+def test_field_is_returned_as_python_object_if_shape_empty_and_no_unit(
+        nxroot, value, type_):
+    nxroot['field1'] = sc.scalar(value, unit=None)
+    field = nxroot['field1'][()]
+    assert isinstance(field, type_)
+    assert field == value
+
+
+@pytest.mark.parametrize('value', [1.2, 123, True, 'abc'])
+def test_field_is_returned_as_variable_if_shape_empty_and_unit(nxroot, value):
+    nxroot['field1'] = sc.scalar(value, unit='K')
+    field = nxroot['field1'][()]
+    assert isinstance(field, sc.Variable)
+
+
 def test_field_getitem_returns_variable_with_correct_size_and_values(nxroot):
     nxroot['field'] = sc.arange('ignored', 6, dtype='int64', unit='ns')
     field = nxroot['field']
